# Plotting API
The main user-facing function is `iplotx.network`, which can be used to plot graphs and graph groupings (covers and clusterings), and `iplotx.tree` to plot trees.

```{tip}
  `iplotx.plot` is a synonym for `iplotx.network`.
```

```{eval-rst}
.. autofunction:: iplotx.network
    :noindex:

.. autofunction:: iplotx.tree
    :noindex:
